cmoncrawl.processor.pipeline.extractor.BaseExtractor.preprocess
===============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: BaseExtractor.preprocess